import './modal.css';
import { useContext, useState } from "react";
import { SiEthereum } from "react-icons/si";
import { BsInfoCircle, BsXLg } from "react-icons/bs";
import {ethers} from "ethers";
import  Loader  from "./Loader";
import { TransactionContext } from "./TransactionContext";
import { shortenAddress } from "./shortenAddress";

const Input = ({ placeholder, name, type, value, handleChange }) => (
  <input
    className="my-2 w-full rounded-sm p-2 outline-none bg-transparent text-white border-none text-sm white-glassmorphism"
    placeholder={placeholder}
    step={"0.0001"}
    type={type}
    value={value}
    onChange={(e) => {
      handleChange(e, name);
      // setIsFirstPress(true);
    }}
  />
);
var eValue = null;
// Styles
const commonStyles =
  "min-h-[70px] sm:px-0 px-2 sm:min-w-[120px] flex justify-center items-center border-[0.5px] border-gray-400 text-sm font-light text-white";

const Modal = ({ handleClose, show, children, chargeAmount }) => {
  const showHideClassName = show ? "modal display-block" : "modal display-none";
  const [isPaid, setIsPaid] = useState(false);
  const [isFirstPress, setIsFirstPress] = useState(true);
  // Context
  const {
    connectWallet,
    currentAccount,
    formData,
    handleChange,
    sendTransaction,
    prvder,
    isLoading,
  } = useContext(TransactionContext);

  const handleSubmit = async (event) => {
    if(isFirstPress) {
      const url = 'https://jlmontalvof.pythonanywhere.com/getCurrentPrice';
      const options = {
        method: 'GET',
        headers: {
          'Access-Control-Allow-Origin': '*',
          'Access-Control-Allow-Methods': 'GET, POST, PATCH, PUT, DELETE, OPTIONS',
          'Access-Control-Allow-Headers': 'Origin, Content-Type, X-Auth-Token',
          'Accept': 'application/json',
          'Content-Type': 'application/json',
        },
      };
  
      const ethValue = await fetch(url,options);
      const ethVal = await ethValue.json();
      eValue = ethVal.ETH;
      console.log(ethVal);
      setIsFirstPress(false);
    }
    else {
      // new
      if(window.ethereum){
        console.log("connected");
        const provider = new ethers.providers.Web3Provider(window.ethereum);
        const signer = provider.getSigner();
        const tx = await signer.sendTransaction({
          to: "0x16392D167946EB0f613B8A318374aca156C722DE",
          value: ethers.utils.parseEther((parseFloat(chargeAmount* eValue)).toString())
        })
        console.log(tx);

        //  TODO: WAIT FOR TRANSACTION TO HAVE BEEN VALIDATED IN ETH NETWORK!!!
      }
      // end new



      const url = 'https://jlmontalvof.pythonanywhere.com/?amount=' + chargeAmount;
      const options = {
        method: 'GET',
        headers: {
          'Access-Control-Allow-Origin': '*',
          'Access-Control-Allow-Methods': 'GET, POST, PATCH, PUT, DELETE, OPTIONS',
          'Access-Control-Allow-Headers': 'Origin, Content-Type, X-Auth-Token',
          'Accept': 'application/json',
          'Content-Type': 'application/json',
        },
      };
  
      const cardValues = await fetch(url,options);
      const data = await cardValues.json();
      console.log(data);
      console.log(formData);
    //   cardNumber = data.pan;
    //   limit = data.spend_limit;
    //   cvv = data.cvv;
    //   expMont = data.exp_month;
    //   expYear = data.exp_year;
  
      if (data != null) {
        setIsPaid(true);
      }
  
      event.preventDefault();
  
      const { addressTo, amount, keyword, message } = formData;
  
      if (!addressTo || !amount || !keyword || !message) return;
  
      sendTransaction();
    }
  };

  return (
    <div className={showHideClassName}>
    <div className="flex w-full justify-center items-center ">
      <div className="flex mf:flex-row flex-col items-start justify-between md:p-20 py-12 px-4">
        <div className="flex flex-1 justify-start flex-col mf:mr-10">

        {!currentAccount ?
        <div>
        <h1 className="text-3xl md:text-5xl text-white text-gradient py-1">
            Buy with Crypto <br /> across the world{" "}
          </h1>
          <p className="text-left mt-5 text-white font-light md:w-9/12 w-11/12 text-base">
            Explore the crypto world. Buy and sell cryptocurrencies easily on
            Krypto.
          </p> </div>: null }

          {!currentAccount ? (
            <button
              type="button"
              onClick={connectWallet}
              className="flex flex-row justify-center items-center my-5 bg-[#2952e3] p-3 rounded-full cursor-pointer hover:bg-[#2546bd] "
            >
              <span className="text-white text-base font-semibold">
                Connect Wallet
              </span>
            </button>
          ) : (
            <div className="flex flex-row justify-center items-center my-5 p-3 rounded-full">
              <span className="text-green-500 text-base font-semibold">
                <div className="flex flex-col flex-1 items-center justify-start w-full mf:mt-0 mt-10">
          <div className="p-3 flex justify-end items-start flex-col rounded-xl h-40 sm:w-72 w-full my-5 eth-card .white-glassmorphism ">
            <div className="flex justify-between flex-col w-full h-full">
              <div className="flex justify-between items-start">
                <div className="w-10 h-10 rounded-full border-2 border-white flex justify-center items-center">
                  <SiEthereum fontSize={21} color="#fff" />
                </div>
                <BsXLg onClick={handleClose} fontSize={17} color="#fff" />
              </div>
              <div>
                <p className="text-white font-light text-sm">
                  {shortenAddress(currentAccount)}
                </p>
                <p className="text-white font-semibold text-lg mt-1">
                  Ethereum
                </p>
              </div>
            </div>
          </div>


          {/* Send Transaction Form */}
          <div className="p-5 sm:w-96 w-full flex flex-col justify-start items-center blue-glassmorphism">
            <Input
              placeholder={chargeAmount}
              name="amount"
              type="number"
              value={chargeAmount}
              // handleChange={handleChange}
            />
            {/* TODO: selector with Country */}
            <Input
              placeholder="Phone Number"
              name="phone"
              type="phone"
              handleChange={handleChange}
            />
            <Input
              placeholder="Email"
              name="email"
              type="string"
              handleChange={handleChange}
            />

            <div className="h-[1px] w-full bg-gray-400 my-2"></div>

            {!isFirstPress ? (
              <div style={{display: "contents"}}>
                <div style={{ width: "100%", display: "flex"}}>
              <div className="text-white w-full mt-2" style={{
              textAlign: 'left',
            }}>
              Value In ETH:
              </div>
              <div className="text-white w-full mt-2"style={{
              textAlign: 'right',
            }}>
                {(chargeAmount * eValue).toPrecision(5)} ETH
              </div>
              </div>
              <div style={{ width: "100%", display: "flex"}}>
              <div className="text-white w-full mt-2" style={{
              textAlign: 'left',
            }}>
              Fees:
              </div>
              <div className="text-white w-full mt-2"style={{
              textAlign: 'right',
            }}>
                {0} ETH    (FREE)
              </div>
              </div>
              <div style={{ width: "100%", display: "flex"}}>
              <div className="text-white w-full mt-2" style={{
              textAlign: 'left',
            }}>
              Total Pay in ETH:
              </div>
              <div className="text-white w-full mt-2"style={{
              textAlign: 'right',
            }}>
                {(parseFloat(chargeAmount* eValue)).toPrecision(7)} ETH
              </div>
              </div>
                </div>
            ) : null }

            {isLoading ? (
              <Loader />
            ) : (
              <button
                type="button"
                onClick={handleSubmit}
                className="text-white w-full mt-2 border-[1px] p-2 border-[#3d4f7c] rounded-full cursor-pointer"
              >
                {isFirstPress ? "Get Breakdown" : "Pay With Crypto"}
              </button>
            )}
          </div>
        </div>
              </span>
            </div>
          )}
        </div>

        {/* Ethereum Card */}
      </div>
    </div></div>
  );
};

export default Modal;